@@ -163,13 +163,17 @@ def get_time(
 
 
 def get_datetime(
-        f: str = '%Y-%m-%d %H:%M:%S'
+        f: str = '%Y-%m-%d %H:%M:%S',
+        utc: bool = False
 ):
     """
     获取当前系统的当前时间格式的时间，精确到秒
     :return: 2018-08-01 14:18:31
     """
-    inner_now = datetime.datetime.now()
+    if utc:
+        inner_now = datetime.datetime.now(pytz.utc)
+    else:
+        inner_now = datetime.datetime.now()
     data_time = inner_now.strftime(f)
     return data_time
 
@@ -287,20 +291,26 @@ def get_timestamp():
 def get_timestamp2datetime(
         timestamp: int = None,
         f: str = "%Y-%m-%d %H:%M:%S",
-        zero_to_none: bool = True
+        zero_to_none: bool = True,
+        utc: bool = False
 ):
     """
     将时间戳转换为datetime时间
     :param timestamp: 同时支持字符串和数字格式
     :param f:
     :param zero_to_none: 将0转换为空值
+    :param utc: 是否为utc时间
     :return: 2018-08-01 14:19:53
     """
     if timestamp is not None:
         if timestamp == 0 and zero_to_none is True:
             return
         else:
-            time_array = time.localtime(timestamp)
+            if utc:
+                time_array = time.gmtime(timestamp)
+            else:
+                time_array = time.localtime(timestamp)
+
             date_time = time.strftime(f, time_array)
             return date_time
     else:
@@ -310,7 +320,8 @@ def get_timestamp2datetime(
 def get_timestamp2date(
         timestamp: int = None,
         f: str = "%Y-%m-%d",
-        zero_to_none: bool = True
+        zero_to_none: bool = True,
+        utc: bool = False
 ):
     """
     将时间戳转换为datetime时间
@@ -318,13 +329,17 @@ def get_timestamp2date(
     :param timestamp:
     :param f:
     :param zero_to_none: 将0转换为空值
+    :param utc: 是否为utc时间
     :return: 2018-08-01 14:19:53
     """
     if timestamp is not None:
         if timestamp == 0 and zero_to_none is True:
             return
         else:
-            time_array = time.localtime(timestamp)
+            if utc:
+                time_array = time.gmtime(timestamp)
+            else:
+                time_array = time.localtime(timestamp)
             date_time = time.strftime(f, time_array)
             return date_time
     else:
@@ -655,6 +670,20 @@ def date_str_list(
     return date_list
 
 
+def get_date_list(
+        start_date: str = None,
+        end_date: str = None,
+        start_days: int = None,
+        end_days: int = None
+):
+    return date_str_list(
+        start_date=start_date,
+        end_date=end_date,
+        start_days=start_days,
+        end_days=end_days
+    )
+
+
 def date_str_list_form_now(
         day_num: int = 1
 ):
@@ -699,14 +728,20 @@ def get_data_date_string(
 
 def get_date_string(
         days: int = 0,
-        f: str = '%Y-%m-%d'
+        f: str = '%Y-%m-%d',
+        utc: bool = False
 ):
     """
     获取多少天以后的时间字符串
     :param days: 多少天以后，正数向未来计算，负数向历史计算，0是当天
+    :param f:
+    :param utc:
     :return: 时间字符串(xxxx-xx-xx)
     """
-    current_time = datetime.datetime.now()
+    if utc:
+        current_time = datetime.datetime.now(tz=pytz.utc)
+    else:
+        current_time = datetime.datetime.now()
     target_time = current_time + datetime.timedelta(days=days)
     date_str = target_time.strftime(f)
     return date_str
@@ -975,3 +1010,13 @@ def get_recent_days_date(
         start_date=get_date_string(days=num_start),
         end_date=get_date_string(days=num_end)
     )
+
+
+def network_timestamp():
+    """
+    获取网络时间，精确到毫秒
+    """
+    url = 'https://api.m.taobao.com/rest/api3.do?api=mtop.common.getTimestamp'  # 淘宝网络取时
+    res = requests.get(url=url)
+    net_t = res.json()['data']['t']  # 精确到毫秒的时间戳
+    return int(net_t)
